==> sympa_6.2.40~dfsg.orig.tar.xz: sympa-6.2.40/AUTHORS.md <==
# Authors

The development of Sympa is a collaborative effort from the users community. However, the following institutions and persons were continuously providing a development effort.

## RENATER

The [RENATER](http://www.renater.fr) team was in charge of maintaining the Sympa project, contribute to the code and merge contributions from developpers all over the world.

Authors of Sympa from RENATER are Étienne Méléard, Olivier Salaün and David Verdin. 

## INRIA

[INRIA](http://www.inria.fr/) is the main French public organization for research in the fields of Computer sciences. INRIA contributed on a regular basis on the evolution of Sympa code.

The Sympa author from INRIA is Guillaume Rousse.

## Legacy...

Serge Aumont and Christophe Wolfhugel are, along with Olivier Salaün, the original authors of Sympa. Even though they no longer work on Sympa, they are the people who made Sympa real and are still giving us precious advices about the development orientations.

# Credits

Our thanks to all contributors:

## Translations

  * Mahmoud Jisri for his Arabic translations
  * Prof. P.E.M. Almeida for his work on Brazilian translations
  * Jordi Deu-Pons and Ana Ribas for their Catalan translations
  * Tung Siu Fai, Wang Jian and Autrijus Tang, Mark Smith, Hun Yan, Li Xuejiang, Zhao Yongming for their Chinese translations.
  * Petr Prazak, Ludek Mokry for his Czech translations.
  * Harry Westerman for his Dutch translations.
  * Jill Gemmill who has revised the English translations
  * Lauri Jesmin, Tanel Kindsigo for their Estonian translations
  * Mikko Bemmu Sepponen, Vesa Alhofor their Finnish translations
  * Carsten Clasohm and Jens-Uwe Gaspar, Harald Wilhelmi, Georg Bauer, Stefan Hornburg, Michael Redinger for their German translations.
  * Vizi Szilard, for his Hungarian translations.
  * Marco Ferrante, Alberto Pasquale, Renato Bonomini, G. Donnini for their Italian translations.
  * Kazuo Moriwaka and Soji Ikeda for their Japanese translations
  * Mark Smith (HP) for his Korean translations
  * Anders Lund and J.Gunnar for their Norwegian Bokmål translations
  * Mòni Allaya who translated Sympa in Occitan
  * Lukasz Zalubski and Łukasz Zygmański, for their Polish translations.
  * Rodrigo Filgueira Prates, for his Portuguese translations.
  * Valics Lehel, for his Romanian translations.
  * Chernysh for his Russian translations
  * Alex Nappa, Josep Roman, Philippe Mingo, Antonio Casado and José Manuel Caínzos for their Spanish translations.
  * Daniel Nylander for his Swedish translations
  * Clytie Siddall for his Vietnamese translations

## Documentation

  * Pierre David, who in addition to his help and suggestions in developing the code, participated more than actively in producing this manual (it was so pretty when managed using latex ;-)
  * Virginie Paitrault, Université de Rennes 2, who wrote the excellent online user documentation.
  * David Lewis, who corrected this reference manual.
  * Laurent Merot who designed the first Sympa logo
  * Doriane Dussart who wrote the Java SOAP client documentation

## Packaging

  * Raphaël Hertzog , Jerome Marant, Jean-Charles Delepine, Stefan Hornburg for the Debian packaging 
  * Stéphane Poirey for his work on RedHat packaging
  * Loic Dachary, for guiding us through the GNU Coding Standards.
  * Guy Paressant, Anne Nicolas, Guillaume Rousse for the Mandriva packaging

## Integration with third-party software

  * John-Paul Robinson, University of Alabama at Birmingham, who added email verification procedure to the Shibboleth support.
  * Thierry Charles and Albert Bruc who introduced the Sybase support
  * Philippe Rivière, for his perseverance in tuning Sympa for Postfix.
  * Vincent Mathieu, Lynda Amadouche, John Dalbec, for their integration of LDAP features in Sympa.
  * Nadia Euzen who introduced antivirus support in Sympa
  * Christian Mock who has extended S/MIME support in Sympa
  * Frederic Connes who introduced postfix-stylealias management
  * Francis Lachapelle, P.Baumgart (British Telecom), Roland Hopferwieser who wrote and extended the LDAP-enabled alias manager

## New features and scripts

  * Gwenaelle Bouteille, who joined the development team for a few months and produced a great job for various feature introduced in V5 (family, RSS, shared document moderation, ...).
  * Hubert Ulliac, for the search functions in the message archive, based on marcsearch.pm.
  * Florent Guilleux, who wrote the Task Manager (and now join CRU team for many other activities)
  * Nadia Euzen, for developing the antivirus scanner plugin.
  * Fabien Marquois, who introduced many new features such as the digest.
  * Soji Ikeda who has made Sympa UTF-8 enabled
  * Patrice Levesque has made the web interface XHTML compliant
  * Adam Bernstein who provided many enhancements for the web interface.
  * Mathieu Peltier who wrote the log rotation script
  * Harald Wilhelmi provided a generic startup script
  * Adrien Brard who added the DB logs and the member pictures features
  * Sylvain Amrani for his great new features : scenario custom conditions and automatic lists based on list families
  * Alice de Bignicourt who introduced the custom user attributes in Sympa
  * Charles Paul who introduces great optimizations of the web interface

## and also

  * Christophe Wolfhugel, the initial developper of Sympa software 
  * Bernard Barbier, without whom Sympa would not have a name : SYMPA = SYsteme de Multi-Postage Automatique
  * all contributors and beta-testers cited in the ChangeLog file, who, by serving as guinea pigs and being the first to use it, made it possible to quickly and efficiently debug the Sympa software.

---
We ask all those we have forgotten to thank to accept our apologies and to let us know, so that we can correct this error in future releases of this documentation.

==> sympa_6.2.76~dfsg.orig.tar.xz: sympa-6.2.76/AUTHORS.md <==
# Authors

The development of Sympa is a collaborative effort from the users community. However, the following institutions and persons have been providing a development effort.

## Legacy...

Serge Aumont and Christophe Wolfhugel are, along with Olivier Salaün, the original authors of Sympa. Even though they no longer work on Sympa, they are the people who made Sympa real and are still giving us precious advices about the development orientations.

## RENATER and INRIA

The [RENATER](http://www.renater.fr) team was in charge of maintaining the Sympa project, contribute to the code and merge contributions from developers all over the world.
Authors of Sympa from RENATER are Étienne Méléard, Olivier Salaün and David Verdin.

[INRIA](http://www.inria.fr/) is the main French public organization for research in the fields of Computer sciences. INRIA contributed on a regular basis on the evolution of Sympa code.
The Sympa author from INRIA is Guillaume Rousse.

## The Sympa Community

Recently, Sympa was forked and handed to the community on GitHub to revitalize development.  In 2017, the first version by [The Sympa Community](https://github.com/sympa-community) was released.

# Credits

Our thanks to all contributors:

## Translations

  * Mahmoud Jisri for his Arabic translations
  * Prof. P.E.M. Almeida for his work on Brazilian translations
  * Jordi Deu-Pons and Ana Ribas for their Catalan translations
  * Tung Siu Fai, Wang Jian and Autrijus Tang, Mark Smith, Hun Yan, Li Xuejiang, Zhao Yongming for their Chinese translations.
  * Petr Prazak, Ludek Mokry for his Czech translations.
  * Harry Westerman for his Dutch translations.
  * Jill Gemmill who has revised the English translations
  * Lauri Jesmin, Tanel Kindsigo for their Estonian translations
  * Mikko Bemmu Sepponen, Vesa Alhofor their Finnish translations
  * Carsten Clasohm and Jens-Uwe Gaspar, Harald Wilhelmi, Georg Bauer, Stefan Hornburg, Michael Redinger for their German translations.
  * Vizi Szilard, for his Hungarian translations.
  * Marco Ferrante, Alberto Pasquale, Renato Bonomini, G. Donnini for their Italian translations.
  * Kazuo Moriwaka and Soji Ikeda for their Japanese translations
  * Mark Smith (HP) for his Korean translations
  * Anders Lund and J.Gunnar for their Norwegian Bokmål translations
  * Mòni Allaya who translated Sympa in Occitan
  * Lukasz Zalubski and Łukasz Zygmański, for their Polish translations.
  * Rodrigo Filgueira Prates, for his Portuguese translations.
  * Valics Lehel, for his Romanian translations.
  * Chernysh for his Russian translations
  * Alex Nappa, Josep Roman, Philippe Mingo, Antonio Casado and José Manuel Caínzos for their Spanish translations.
  * Daniel Nylander for his Swedish translations
  * Clytie Siddall for his Vietnamese translations

## Documentation

  * Pierre David, who in addition to his help and suggestions in developing the code, participated more than actively in producing this manual (it was so pretty when managed using latex ;-)
  * Virginie Paitrault, Université de Rennes 2, who wrote the excellent online user documentation.
  * David Lewis, who corrected this reference manual.
  * Laurent Merot who designed the first Sympa logo
  * Doriane Dussart who wrote the Java SOAP client documentation

## Packaging

  * Raphaël Hertzog , Jerome Marant, Jean-Charles Delepine, Stefan Hornburg for the Debian packaging 
  * Stéphane Poirey for his work on RedHat packaging
  * Loic Dachary, for guiding us through the GNU Coding Standards.
  * Guy Paressant, Anne Nicolas, Guillaume Rousse for the Mandriva packaging

## Integration with third-party software

  * John-Paul Robinson, University of Alabama at Birmingham, who added email verification procedure to the Shibboleth support.
  * Thierry Charles and Albert Bruc who introduced the Sybase support
  * Philippe Rivière, for his perseverance in tuning Sympa for Postfix.
  * Vincent Mathieu, Lynda Amadouche, John Dalbec, for their integration of LDAP features in Sympa.
  * Nadia Euzen who introduced antivirus support in Sympa
  * Christian Mock who has extended S/MIME support in Sympa
  * Frederic Connes who introduced postfix-stylealias management
  * Francis Lachapelle, P.Baumgart (British Telecom), Roland Hopferwieser who wrote and extended the LDAP-enabled alias manager

## New features and scripts

  * Gwenaelle Bouteille, who joined the development team for a few months and produced a great job for various feature introduced in V5 (family, RSS, shared document moderation, ...).
  * Hubert Ulliac, for the search functions in the message archive, based on marcsearch.pm.
  * Florent Guilleux, who wrote the Task Manager (and now join CRU team for many other activities)
  * Nadia Euzen, for developing the antivirus scanner plugin.
  * Fabien Marquois, who introduced many new features such as the digest.
  * Soji Ikeda who has made Sympa UTF-8 enabled
  * Patrice Levesque has made the web interface XHTML compliant
  * Adam Bernstein who provided many enhancements for the web interface.
  * Mathieu Peltier who wrote the log rotation script
  * Harald Wilhelmi provided a generic startup script
  * Adrien Brard who added the DB logs and the member pictures features
  * Sylvain Amrani for his great new features : scenario custom conditions and automatic lists based on list families
  * Alice de Bignicourt who introduced the custom user attributes in Sympa
  * Charles Paul who introduces great optimizations of the web interface

## and also

  * Christophe Wolfhugel, the initial developper of Sympa software 
  * Bernard Barbier, without whom Sympa would not have a name : SYMPA = SYsteme de Multi-Postage Automatique
  * all contributors and beta-testers cited in the ChangeLog file, who, by serving as guinea pigs and being the first to use it, made it possible to quickly and efficiently debug the Sympa software.

---
We ask all those we have forgotten to thank to accept our apologies and to let us know, so that we can correct this error in future releases of this documentation.
